; iNes format header
  .inesprg 1   ; 1x 16KB PRG code
  .ineschr 1   ; 1x  8KB CHR data
  .inesmap 0   ; mapper 0 = NROM, no bank swapping
  .inesmir 1   ; background mirroring

; *** CONSTANTS

; *** VARIABLES
  .rsset $0000	; pointers in 0 page
PrintStrLo .rs 1
PrintStrHi .rs 1
PrintScreenLo .rs 1
PrintScreenHi .rs 1
MapPtr .rs 2

  .rsset $0300 ; regular variables
TempX .rs 1
TempY .rs 1
TempTile .rs 1
TempSize .rs 1
RectX1 .rs 1
RectY1 .rs 1
RectX2 .rs 1
RectY2 .rs 1
SpriteHit .rs 1
MonsterBeingProcessed .rs 1
Level .rs 1

; *** MACROS


; first 8k PRG block 

  .bank 0
  .org $C000 
  
; standard reset code seen in various tutorials
; it resets stack and clears memory then sets palette

RESET:
  SEI          ; disable IRQs
  CLD          ; disable decimal mode
  LDX #$40
  STX $4017    ; disable APU frame IRQ
  LDX #$FF
  TXS          ; Set up stack
  INX          ; now X = 0
  STX $2000    ; disable NMI
  STX $2001    ; disable rendering
  STX $4010    ; disable DMC IRQs

vblankwait1:       ; First wait for vblank to make sure PPU is ready
  BIT $2002
  BPL vblankwait1

clrmem:
  LDA #$00
  STA $0000, x
  STA $0100, x
  STA $0300, x
  STA $0400, x
  STA $0500, x
  STA $0600, x
  STA $0700, x
  LDA #$FE		; Make sure sprites off screen
  STA $0200, x
  INX
  BNE clrmem
   
  JSR WaitForVBlank	; Second wait for vblank, PPU is ready after this
  
LoadPalettes:
  LDA $2002             ; read PPU status to reset the high/low latch
  LDA #$3F
  STA $2006             ; write the high byte of $3F00 address
  LDA #$00
  STA $2006             ; write the low byte of $3F00 address
  LDX #$00              ; start out at 0
LoadPalettesLoop:
  LDA palette, x        ; load data from address (palette + the value in x)
  STA $2007             ; write to PPU
  INX                   ; X = X + 1
  CPX #$20              ; Compare X to hex $10, decimal 16 - copying 16 bytes = 4 sprites
  BNE LoadPalettesLoop  ; Branch to LoadPalettesLoop if compare was Not Equal to zero
                        ; if compare was equal to 32, keep going down

; end of general init code, now my skeleton code

Title_Screen:
  JSR WaitForVBlank
  LDA #$00
  STA $2001    ; disable rendering
  JSR ClearScreen
  ; print title
  LDX #$0A
  LDY #$08
  JSR SetCursorXY
  LDA #HIGH(title_string)
  STA PrintStrHi
  LDA #LOW(title_string)
  STA PrintStrLo
  JSR Print
  ; print start messafe
  LDX #$0A
  LDY #$0B
  JSR SetCursorXY
  LDA #HIGH(title_click_msg)
  STA PrintStrHi
  LDA #LOW(title_click_msg)
  STA PrintStrLo
  JSR Print
  ; print byline message
  LDX #$03
  LDY #$1A
  JSR SetCursorXY
  LDA #HIGH(byline_string)
  STA PrintStrHi
  LDA #LOW(byline_string)
  STA PrintStrLo
  JSR Print
  ; print copyright message
  LDX #$00
  LDY #$1B
  JSR SetCursorXY
  LDA #HIGH(copyright_string)
  STA PrintStrHi
  LDA #LOW(copyright_string)
  STA PrintStrLo
  JSR Print
; reset level to zero
  LDA #$00
  STA Level
; set scrolling and screen enable screen
  STA $2005
  STA $2005
  LDA #%00001010   ; enable background
  STA $2001
  
titleLoop:
  JSR ReadJoystick
  CMP BUTTON_START
  BNE titleLoop
  
GameScreen:
  ; Set up sprite memory
  LDA #$70
  STA $200		; Sprite Y
  LDA #$80
  STA $203		; Sprite X
  LDA #$06
  STA $201		; Sprite ID
  LDA #%00000000
  STA $202		; Sprite Flags
  ; treasure chest is sprites 1..4
  LDA #$08		; tile ID for top left
  STA $205
  LDA #$09		; tile id for top right
  STA $209
  LDA #$18		; tile id for bottom left
  STA $20D
  LDA #$19		; tile id for bottom right
  STA $211
  LDA #$01		; flags - palette #1
  STA $206
  STA $20A
  STA $20E
  STA $212
  ; Monster Sprites
  LDX #$01	; Start with ID offset
game_initMonstersLoop
  LDA #$07
  STA $214,X
  INX
  LDA #$02	; flags - use palette $2
  STA $214,X
  INX
  INX
  INX
  CPX #$19
  BNE game_initMonstersLoop
  ; set up game background - right now just blank  
  JSR WaitForVBlank
  LDA #$00
  STA $2001    ; disable rendering
  JSR DrawMap
  LDA #$00
  STA $2005
  STA $2005
  LDA #%00011010   ; enable sprite and background
  STA $2001

gameLoop:
  ; update sprites - manually as only a few, if lots use DMA
  LDA #$00
  STA $2003	; sprite 0 to be updated
  TAX
gameWriteSpritesLoop:
  LDA $200,X
  STA $2004
  INX
  CPX $2C
  BNE gameWriteSpritesLoop
  
  ; Process input
  JSR ReadJoystick;
  LDX $203
  LDY $200
  BIT BUTTON_UP
  BEQ gameDownCheck
  DEY
gameDownCheck:
  BIT BUTTON_DOWN
  BEQ gameLeftCheck
  INY
gameLeftCheck:
  BIT BUTTON_LEFT
  BEQ gameRightCheck
  DEX
gameRightCheck:
  BIT BUTTON_RIGHT
  BEQ gameJoyDone
  INX
gameJoyDone:
  ;STA $100 ; debug
  ;JSR GetMapTile
  LDA #$07
  JSR IsBlocked
  CMP #$00
  BNE gameProcessEnemies
  STX $203
  STY $200

gameProcessEnemies:
  LDX #$00		; start with y coordinate byte
gameProcessEnemiesLoop:
  LDA $214,X
  TAY
  INX 			; Skip ID Byte
  INX			; Get attributes
  LDA $214,X
  INX			; get ready for X coordinate load
  STX MonsterBeingProcessed
  AND #$40		; see which dir monster moving
  BEQ gameMonsterMovingLeft
  ; process right movement
  LDA $214,X
  TAX
  INX
  LDA #$07
  JSR IsBlocked
  CMP #0
  BEQ gameProcessNextEnemy
  LDX MonsterBeingProcessed
  DEX
  LDA $214,X		; Toggle direction
  EOR #$40
  STA $214,X
  INX
  LDA $214,X
  TAX
  JMP gameProcessNextEnemy
gameMonsterMovingLeft:
  LDA $214,X
  TAX
  DEX
  LDA #$07
  JSR IsBlocked
  CMP #0
  BEQ gameProcessNextEnemy
  LDX MonsterBeingProcessed
  DEX
  LDA $214,X		; Toggle direction
  EOR #$40
  STA $214,X
  INX
  LDA $214,X
  TAX

gameProcessNextEnemy:
  TXA
  LDX MonsterBeingProcessed
  STA $214,X
  INX
  CPX #$17
  BPL gameCheckSpriteHit
  JMP gameProcessEnemiesLoop
  
gameCheckSpriteHit:
  ; build hitbox for player
  LDA $200
  STA RectY1;
  CLC
  ADC #$07
  STA RectY2
  LDA $203
  STA RectX1
  CLC
  ADC #$07
  STA RectX2
  LDA #$00
  STA SpriteHit
  LDY #$01
  ; loop through sprites
gameCheckSpriteLoop:
  TYA
  ASL A
  ASL A
  TAX
  LDA $200,X
  CMP RectY2
  BPL gameCheckSpriteNext
  CLC
  ADC #$07
  CMP RectY1
  BMI gameCheckSpriteNext
  INX
  INX
  INX
  LDA $200,X
  CMP RectX2
  BPL gameCheckSpriteNext
  CLC
  ADC #$07
  CMP RectX1
  BMI gameCheckSpriteNext
  STY SpriteHit
gameCheckSpriteNext:
  INY
  CPY #$0B
  BNE gameCheckSpriteLoop
  LDA SpriteHit
  BEQ gameCheckSpritesDone
  CMP #$05
  BPL gameLose
  INC Level
  LDA Level
  CMP #$04
  BNE gameLose ; actually starts next level now
  JMP WinScreen 
gameLose:
  JMP GameScreen
  
gameCheckSpritesDone:
  JSR WaitForVBlank
  JMP gameLoop;
  
  
WinScreen:  
  JSR WaitForVBlank
  LDA #$00
  STA $2001    ; disable rendering
  JSR ClearScreen
  ; print win
  LDX #$0A
  LDY #$08
  JSR SetCursorXY
  LDA #HIGH(win_string)
  STA PrintStrHi
  LDA #LOW(win_string)
  STA PrintStrLo
  JSR Print
  ; print thanks
  LDX #$07
  LDY #$0B
  JSR SetCursorXY
  LDA #HIGH(thanks_msg)
  STA PrintStrHi
  LDA #LOW(thanks_msg)
  STA PrintStrLo
  JSR Print
  LDA #$00
; set scrolling and screen enable screen
  STA $2005
  STA $2005
  LDA #%00001000   ; enable background
  STA $2001
  
winLoop:
  JSR ReadJoystick
  AND #$F0
  BEQ winLoop
  JMP Title_Screen
  
;---------Functions

WaitForVBlank:
  BIT $2002
  BPL WaitForVBlank
  RTS

ClearScreen:
  LDY #$04
  LDX #$40
  LDA #$00
  LDA $2002             ; read PPU status to reset the high/low latch
  LDA #$20
  STA $2006             ; write the high byte of screen address
  LDA #$00
  STA $2006             ; write the low byte of screen address
clearScreenLoop:
  STA $2007
  INX
  BNE clearScreenLoop
  DEY
  BNE clearScreenLoop
; fill out attribute table
  LDX #$40
  LDA #$00
clearScreen_attributeFill:
  STA $2007
  DEX
  BNE clearScreen_attributeFill
  RTS

SetCursorXY:
  ; calculate the high byte (Every 8 rows increases High byte)
  TYA
  LSR A
  LSR A
  LSR A
  CLC
  ADC #$20
  STA PrintScreenHi
  ; Finding Y portion of screen address by multipying by 32
  TYA
  AND #$07
  LDY #5
setCursorXYLoop:
  ASL A
  DEY
  BNE setCursorXYLoop
  ; add X to it
  STA PrintScreenLo
  TXA
  ORA PrintScreenLo
  STA PrintScreenLo
  RTS
  
Print:
;  LDA $2002             ; read PPU status to reset the high/low latch
  LDA PrintScreenHi
  STA $2006             ; write the high byte of screen address
  LDA PrintScreenLo
  STA $2006             ; write the low byte of screen address
  LDY #$00
print_loop:
  LDA [PrintStrLo],Y
  BEQ print_done
  STA $2007
  INY
  JMP print_loop
print_done:
  RTS;
   
   
   
ReadJoystick:
  ; strobe the controllers so will send button bits
  LDA #$01
  STA $4016
  LDA #$00
  STA $4016
  ; now loop through buttons to build joystick value
  ; a,b,select,start,up,down,left,right
  LDY #$00
  LDX #$08
pollJoy1:
  LDA $4016 		; read bit
  AND #$01		; check if set (button down)
  BEQ adjustJoyBits
  INY			; as bit 0 is 0 will set bit!
adjustJoyBits:
  TYA			 
  DEX			; loop through button bits
  			; done here so won't over-shift flagset
  BEQ doneJoy1
  ASL A			; shift button flag bits over
  TAY
  JMP pollJoy1
doneJoy1:
  RTS
  
DrawMap:
  LDA #LOW(MAP_DATA)
  STA MapPtr
  LDA #HIGH(MAP_DATA)
  CLC
  ADC Level
  STA MapPtr+1
  LDA $2002             ; read PPU status to reset the high/low latch
  LDA #$20
  STA $2006             ; write the high byte of screen address
  LDA #$00
  STA $2006             ; write the low byte of screen address
  LDY #$00
drawMap_topLoop:
  LDA [MapPtr],Y
  BEQ drawMap_floorTop
  LDA #$02
  STA $2007
  LDA #$03
  STA $2007  
  JMP drawMap_toptileDrawn
drawMap_floorTop:
  LDA #$04
  STA $2007
  LDA #$05
  STA $2007    
drawMap_toptileDrawn:
  INY
  TYA
  AND #$0F
  BNE drawMap_topLoop
  
  TYA
  SEC
  SBC #$10
  TAY
drawMap_bottomLoop:
  LDA [MapPtr],Y
  BEQ drawMap_floorBottom
  LDA #$12
  STA $2007
  LDA #$13
  STA $2007  
  JMP drawMap_bottomTileDrawn
drawMap_floorBottom:
  LDA #$14
  STA $2007
  LDA #$15
  STA $2007    
drawMap_bottomTileDrawn:
  INY
  TYA
  AND #$0F
  BNE drawMap_bottomLoop
  ; see if finished map
  CPY #$F0
  BNE drawMap_topLoop
; fill out attribute table
  LDX #$40
  LDA #%01010101
drawMap_attributeFill:
  STA $2007
  DEX
  BNE drawMap_attributeFill
  ; set up player position
  LDA [MapPtr],Y
  STA $203
  INY
  LDA [MapPtr],Y
  STA $200
  ; set up treasure chest
  INY
  LDA [MapPtr],Y
  STA $207
  STA $20F
  CLC
  ADC #$08
  STA $20B
  STA $213
  INY
  LDA [MapPtr],Y
  STA $204
  STA $208
  CLC
  ADC #$08
  STA $20C
  STA $210
  ; set up monsters
  LDX #$03
drawMap_setMonstersLoop:
  INY
  LDA [MapPtr],Y
  STA $214,X
  DEX
  DEX
  DEX
  INY
  LDA [MapPtr],Y
  STA $214,X
  TXA
  CLC
  ADC #$07
  CMP #$1B
  BEQ drawMap_done
  TAX
  JMP drawMap_setMonstersLoop
drawMap_done:  
  RTS
  
; x and y hold target location and are retained
; tile id returned in A
GetMapTile:
  STY TempY
  STX TempX
  TYA
  AND #$F0
  STA TempTile
  TXA
  LDX #$04
GetMapTile_loop:
  LSR A
  DEX
  BNE GetMapTile_loop
  ORA TempTile
  TAY
  LDA [MapPtr],Y
  LDX TempX
  LDY TempY
  RTS
  
; x and y hold target, A is bounding square size
; returns 1 if blocked
IsBlocked:
  ; fill out bounding rect
  STA TempSize
  STX RectX1
  TXA
  CLC
  ADC TempSize
  STA RectX2
  STY RectY1
  TYA
  CLC
  ADC TempSize
  STA RectY2
  ; check top left
  JSR GetMapTile
  CMP #$01
  BEQ IsBlocked_done
  ; check top right
  LDX RectX2
  JSR GetMapTile
  CMP #$01
  BEQ IsBlocked_done
  ; check bottom right
  LDY RectY2
  JSR GetMapTile
  CMP #$01
  BEQ IsBlocked_done
  ; check bottom left
  LDX RectX1
  JSR GetMapTile  
IsBlocked_done:
  LDX RectX1
  LDY RectY1
  RTS
  
; ---------------------------

  .bank 1
  .org $E000
palette:
  .db $0F,$19,$2B,$39, $0F,$17,$16,$06, $0F,$39,$3A,$3B, $0F,$3D,$3E,$0F
;  .db $0F,$19,$2B,$39, $07,$0F,$16,$06, $0F,$39,$3A,$3B, $0F,$3D,$3E,$0F
  .db $0F,$14,$27,$39, $0F,$27,$06,$2D, $0F,$0A,$29,$25, $0F,$02,$38,$3C
	; BIT and Joypad constants
BITS:
BUTTON_A: .db $80
BUTTON_B: .db $40
BUTTON_SELECT: .db $20
BUTTON_START: .db $10
BUTTON_UP: .db $08
BUTTON_DOWN: .db $04
BUTTON_LEFT: .db $02
BUTTON_RIGHT: .db $01

title_string:
  .db "TREASURE RUN", $00
title_click_msg:
  .db "START TO BEGIN", $00
byline_string:
  .db "CREATED BY BILLY D SPELCHAN", $00
copyright_string:
  .db "COPYRIGHT 2013 BLAZING GAMES INC", $00

win_string:
  .db "YOU HAVE WON", $00
thanks_msg:
  .db "THANKS FOR PLAYING", $00
  
MAP_DATA:

; level 0
  .db 1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1
  .db 1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1 
  .db 1,0,1,1,1,1,1,1,1,1,1,1,1,1,0,1
  .db 1,0,1,0,0,0,0,0,0,0,0,0,0,1,0,1
  .db 1,0,1,0,1,1,1,1,1,1,1,1,0,1,0,1 
  .db 1,0,1,0,1,0,0,0,0,0,0,1,0,1,0,1
  .db 1,0,1,0,1,0,1,1,1,1,0,1,0,1,0,1
  .db 1,0,1,0,1,0,0,0,0,1,0,1,0,1,0,1
  .db 1,0,1,0,1,1,1,1,1,1,0,1,0,1,0,1
  .db 1,0,1,0,0,0,0,0,0,0,0,1,0,1,0,1
  .db 1,0,1,1,1,1,1,1,1,1,1,1,0,1,0,1
  .db 1,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1
  .db 1,1,1,1,1,1,1,1,1,1,1,1,1,1,0,1
  .db 1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1
  .db 1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1
  ; level data:	player x,y,
  ;		treasure x,y
  ;		monster x,y * 6
  .db $18,$D8,$80,$70,$F0,$F0,$F0,$F0,$F0,$F0,$F0,$F0,$F0,$F0,$F0,$F0

  ; level 1
  .db 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1
  .db 1, 0, 0, 1, 1, 0, 0, 1, 1, 1, 1, 1, 1, 1, 1, 1 
  .db 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1
  .db 1, 0, 0, 1, 1, 1, 1, 1, 0, 0, 1, 1, 1, 0, 0, 1
  .db 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 0, 0, 1 ;$4
  .db 1, 1, 1, 1, 0, 0, 1, 1, 1, 1, 1, 1, 0, 0, 0, 1 
  .db 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1
  .db 1, 0, 0, 1, 1, 1, 1, 1, 0, 0, 1, 1, 1, 1, 1, 1 
  .db 1, 0, 0, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1 ; $8
  .db 1, 0, 0, 0, 0, 1, 1, 1, 1, 1, 1, 1, 1, 0, 0, 1
  .db 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1 ; $A
  .db 1, 1, 1, 1, 1, 1, 1, 1, 0, 0, 1, 1, 1, 1, 0, 1
  .db 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 0, 1 ; $C
  .db 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1
  .db 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1
  ;    px  py  tx  ty m1x m1y m2x m2y m3x m3y m4x m4y m5x m5y m6x m6y
  .db $17,$D7,$10,$10,$18,$A7,$E7,$67,$17,$27,$F0,$F0,$F0,$F0,$F0,$F0

  ; level 2
  .db 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1
  .db 1, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1
  .db 1, 0, 1, 0, 1, 0, 1, 1, 0, 1, 1, 1, 0, 1, 1, 1
  .db 1, 0, 1, 0, 1, 0, 0, 1, 0, 0, 0, 1, 1, 1, 0, 1
  .db 1, 0, 1, 0, 1, 1, 0, 1, 1, 1, 0, 0, 0, 0, 0, 1 ; $4
  .db 1, 0, 1, 0, 1, 0, 0, 0, 0, 1, 0, 1, 1, 1, 0, 1
  .db 1, 0, 1, 0, 1, 0, 1, 1, 1, 1, 0, 1, 1, 1, 0, 1
  .db 1, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1
  .db 1, 0, 1, 1, 1, 1, 1, 1, 0, 1, 1, 1, 1, 1, 0, 1 ; $8
  .db 1, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 1
  .db 1, 1, 1, 1, 1, 0, 1, 1, 1, 1, 0, 1, 1, 1, 0, 1 ; $A
  .db 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 1
  .db 1, 1, 0, 1, 1, 1, 1, 0, 1, 1, 1, 1, 0, 1, 1, 1
  .db 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1
  .db 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1 ; $E
  ;    px  py  tx  ty m1x m1y m2x m2y m3x m3y m4x m4y m5x m5y m6x m6y
  .db $17,$D7,$E0,$10,$54,$14,$E4,$44,$A4,$74,$54,$94,$54,$B4,$A4,$94

  ; level 3
  ;   0          $4          $8,   $A    $C       $F
  .db 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1
  .db 1, 1, 1, 0, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 1
  .db 1, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 1, 1, 1, 0, 1
  .db 1, 0, 1, 1, 1, 0, 1, 1, 1, 0, 0, 0, 0, 0, 0, 1
  .db 1, 0, 1, 0, 1, 1, 1, 0, 1, 0, 1, 0, 1, 1, 1, 1 ; $4
  .db 1, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 1, 1, 1, 1, 1
  .db 1, 1, 1, 1, 1, 0, 1, 0, 1, 0, 0, 0, 0, 0, 0, 1
  .db 1, 1, 0, 1, 1, 1, 1, 0, 1, 1, 1, 1, 1, 1, 0, 1
  .db 1, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 1, 0, 1 ; $8
  .db 1, 0, 1, 1, 1, 0, 1, 1, 1, 0, 1, 1, 0, 1, 0, 1
  .db 1, 0, 1, 0, 1, 1, 1, 1, 1, 0, 1, 0, 0, 1, 0, 1 ; $A
  .db 1, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 1, 1, 1, 0, 1
  .db 1, 1, 1, 1, 1, 1, 1, 0, 1, 0, 1, 1, 0, 1, 0, 1
  .db 1, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 1
  .db 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1 ; $E
  ;    px  py  tx  ty m1x m1y m2x m2y m3x m3y m4x m4y m5x m5y m6x m6y
  .db $17,$D7,$B0,$A0,$14,$24,$54,$54,$34,$84,$74,$B4,$B4,$34,$C4,$D4

NMI:
  ; DMA code if using NMI
  ; probably won't use but its a small amount of code
  LDA #$00
  STA $2003  ; set the low byte of the DMA RAM address
  LDA #$02
  STA $4014  ; set the high byte of the DMA RAM address, start the transfer
  RTI
  
  .org $FFFA     ;first of the three jump vectors starts here
  .dw NMI        ; Jump for NMIs if enabled;
  .dw RESET      ; jump for when RESET or first turned on
  .dw 0          ;external interrupt IRQ is not used
  
 ; ---------------------------

  .bank 2
  .org $0000
  .incbin "tileset.chr"   ;includes 8KB graphics file from SMB1
